@@ -34,6 +34,7 @@ import shutil
 import threading
 import atexit
 import tempfile
+import pathlib
 try:
   from string import maketrans
 except ImportError:
@@ -620,6 +621,9 @@ class SoftwareProperties(object):
         break
     else:
       print("No config found, creating one")
+      dirname = os.path.dirname(f)
+      if not os.path.exists(dirname):
+        pathlib.Path(dirname).mkdir(parents=True)
       open(conffiles[0], "w")
 
     # ensure /etc/cron.daily/apt is executable
